@@ -3,9 +3,11 @@ import re
 import scipy.interpolate as interpolate
 import numpy as np
 from nctoolkit.api import open_data, open_thredds
+from tqdm import tqdm
 
 
-def matchup(self,  tmean = False):
+
+def matchup(self,  tmean = False, regrid = "bil"):
     """
     Matchup gridded model and point observational data
     Parameters
@@ -18,6 +20,9 @@ def matchup(self,  tmean = False):
     tmean: bool
         Set to True or False, depending on whether you want temporal averaging at the level given by on. Defaults to False.
         This is equivalent to doing `ds.tmean(on)` to the dataset.
+    regrid: str
+        Regridding method. Defaults to "bil". Options available are those in nctoolkit regrid method.
+        "nn" for nearest neighbour.
 
     """
 
@@ -64,7 +69,7 @@ def matchup(self,  tmean = False):
     ds.run()
     ds.assign(target = lambda x: isnan(x.target))
     df = points.loc[:,["lon", "lat"]].drop_duplicates()
-    ds.regrid(df)
+    ds.regrid(df, method = regrid)
     grid = ds.to_dataframe().reset_index().dropna().loc[:,["lon", "lat"]].drop_duplicates()
 
     n_start = len(points)
@@ -106,8 +111,8 @@ def matchup(self,  tmean = False):
         if on != ["all"]:
             if tmean is False:
                 df_times = self.data_times
-                point_col = [x for x in df_times.columns if x in self.points.columns]
-                df_times = self.data_times.merge(self.points.loc[:,point_col]).drop_duplicates()
+                point_col = [x for x in df_times.columns if x in points.columns]
+                df_times = self.data_times.merge(points.loc[:,point_col]).drop_duplicates()
             else:
 
                 if on == ["day"]:
@@ -142,12 +147,13 @@ def matchup(self,  tmean = False):
 
     df_merged = []
 
+
     # depths only need to be calculated once
     if self.depths is not None:
         if type(self.depths) is not list:
             ds_depths = self.depths.copy()
             obs_locs = points.loc[:,["lon", "lat"]]
-            ds_depths.regrid(obs_locs, "bil")
+            ds_depths.regrid(obs_locs, method = regrid) 
             df_depths = (
                 ds_depths.to_dataframe()
                 .reset_index()
@@ -168,13 +174,16 @@ def matchup(self,  tmean = False):
                 ds = open_data(self.data, checks = False)
             if self.variables is not None:
                 ds.subset(variables = self.variables)
-            ds.regrid(points.loc[:,["lon", "lat"]], "bil")
+            ds.regrid(points.loc[:,["lon", "lat"]], method = regrid) 
             df_merged = [ds.to_dataframe().reset_index()]
             points_merged = True
 
     if points_merged is False:
 
-        for i in range(0, len(df_times)):
+        df_times = df_times.sample(frac = 1)
+
+        print("Looping through times in ds and df to matchup")
+        for i in tqdm(range(0, len(df_times))):
             if self.temporal:
                 i_df = df_times.iloc[
                     i : (i + 1) :,
@@ -252,7 +261,7 @@ def matchup(self,  tmean = False):
             if self.data_nan is not None:
                 ds.set_missing(self.data_nan)
 
-            ds.regrid(i_grid, "bil")
+            ds.regrid(i_grid, method = regrid) 
 
             df_model = ds.to_dataframe().drop_duplicates().reset_index().drop_duplicates()
 
@@ -406,6 +415,9 @@ def matchup(self,  tmean = False):
         except:
             df_merged = orig_df
 
+    if "path" in df_merged.columns:
+        df_merged = df_merged.drop(columns = "path")
+
     self.values = df_merged
 
 
