@@ -1,11 +1,3 @@
-import inspect
-import warnings
-
-from nctoolkit.runthis import run_this
-
-
-
-
 def sum_all(self, drop=True):
     """
     Calculate the sum of all variables for each time step
@@ -18,11 +10,17 @@ def sum_all(self, drop=True):
 
     self.run()
 
-    if (len(self) > 1) and (self._merged is False):
-        raise TypeError("This only works for single files presently")
+    contents = self.contents
+
+    easy = False
+    if len(self) > 1:
+        if len(set(self.contents.reset_index().loc[:,["file", "variable"]].groupby("variable").size())):
+            easy = True
+
+    if (len(self) > 1 and easy is False) and (self._merged is False):
+        raise TypeError("This currently only works for datasets with files with the same variables")
 
     if drop is True:
-        # self.transmute({"total": "+".join(self.variables)})
         self.cdo_command("expr,total=" + "+".join(self.variables))
 
     else:
